@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2021 Aspose.Cells Cloud
+Copyright (c) 2022 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -133,14 +133,14 @@ __PACKAGE__->method_documentation({
     	read_only => '',
     		},
     'max_value' => {
-    	datatype => 'object',
+    	datatype => 'int',
     	base_name => 'MaxValue',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'value' => {
-    	datatype => 'object',
+    	datatype => 'int',
     	base_name => 'Value',
     	description => '',
     	format => '',
@@ -150,8 +150,8 @@ __PACKAGE__->method_documentation({
 
 __PACKAGE__->swagger_types( {
     'dynamic_filter_type' => 'string',
-    'max_value' => 'object',
-    'value' => 'object'
+    'max_value' => 'int',
+    'value' => 'int'
 } );
 
 __PACKAGE__->attribute_map( {
